@@ -1239,7 +1239,8 @@ vkgraph.VkDataType = {
     FLOAT16: 4,
     FLOAT32: 5,
     FLOAT64: 6,
-    INT64: 7
+    INT64: 7,
+    UNSET: 127
 };
 
 vkgraph.VkStorageType = {
@@ -1253,6 +1254,8 @@ vkgraph.VkMemoryLayout = {
     TENSOR_WIDTH_PACKED: 0,
     TENSOR_HEIGHT_PACKED: 1,
     TENSOR_CHANNELS_PACKED: 2,
+    PACKED_INT8_4W4C: 3,
+    PACKED_INT8_4H4W: 4,
     DEFAULT_LAYOUT: 255
 };
 
@@ -1266,6 +1269,7 @@ vkgraph.VkTensor = class VkTensor {
         $.mem_obj_id = reader.int32_(position, 10, 0);
         $.storage_type = reader.uint8_(position, 12, 255);
         $.memory_layout = reader.uint8_(position, 14, 255);
+        $.staging_datatype = reader.int8_(position, 16, 127);
         return $;
     }
 };
